==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-kafka/include/aws/kafka/model/PublicAccess.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/kafka/Kafka_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Kafka
{
namespace Model
{

  /**
   * Public access control for brokers.<p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/kafka-2018-11-14/PublicAccess">AWS
   * API Reference</a></p>
   */
  class AWS_KAFKA_API PublicAccess
  {
  public:
    PublicAccess();
    PublicAccess(Aws::Utils::Json::JsonView jsonValue);
    PublicAccess& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline const Aws::String& GetType() const{ return m_type; }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline void SetType(const Aws::String& value) { m_typeHasBeenSet = true; m_type = value; }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline void SetType(Aws::String&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline void SetType(const char* value) { m_typeHasBeenSet = true; m_type.assign(value); }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline PublicAccess& WithType(const Aws::String& value) { SetType(value); return *this;}

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline PublicAccess& WithType(Aws::String&& value) { SetType(std::move(value)); return *this;}

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline PublicAccess& WithType(const char* value) { SetType(value); return *this;}

  private:

    Aws::String m_type;
    bool m_typeHasBeenSet;
  };

} // namespace Model
} // namespace Kafka
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-kafka/include/aws/kafka/model/PublicAccess.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/kafka/Kafka_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Kafka
{
namespace Model
{

  /**
   * Public access control for brokers.<p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/kafka-2018-11-14/PublicAccess">AWS
   * API Reference</a></p>
   */
  class AWS_KAFKA_API PublicAccess
  {
  public:
    PublicAccess();
    PublicAccess(Aws::Utils::Json::JsonView jsonValue);
    PublicAccess& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline const Aws::String& GetType() const{ return m_type; }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline bool TypeHasBeenSet() const { return m_typeHasBeenSet; }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline void SetType(const Aws::String& value) { m_typeHasBeenSet = true; m_type = value; }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline void SetType(Aws::String&& value) { m_typeHasBeenSet = true; m_type = std::move(value); }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline void SetType(const char* value) { m_typeHasBeenSet = true; m_type.assign(value); }

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline PublicAccess& WithType(const Aws::String& value) { SetType(value); return *this;}

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline PublicAccess& WithType(Aws::String&& value) { SetType(std::move(value)); return *this;}

    /**
     * 
            <p>The value DISABLED indicates that public access is turned off.
     * SERVICE_PROVIDED_EIPS indicates that public access is turned on.</p>
         
     */
    inline PublicAccess& WithType(const char* value) { SetType(value); return *this;}

  private:

    Aws::String m_type;
    bool m_typeHasBeenSet = false;
  };

} // namespace Model
} // namespace Kafka
} // namespace Aws
